package com.cyl.manager.act.controller;

import java.util.List;

import com.cyl.manager.act.domain.entity.ActivityApplyInfo;
import com.cyl.manager.act.domain.query.ActivityApplyInfoQuery;
import com.cyl.manager.act.service.ActivityApplyInfoService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.Pageable;
import org.springframework.data.domain.Page;
import org.springframework.http.ResponseEntity;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
/**
 * 活动报名信息Controller
 *
 * @author zcc
 * @date 2024-07-31
 */
@Api(description ="活动报名信息接口列表")
@RestController
@RequestMapping("/act/activityApplyInfo")
public class ActivityApplyInfoController extends BaseController {
    @Autowired
    private ActivityApplyInfoService service;


    @ApiOperation("查询活动报名信息列表")
    @PreAuthorize("@ss.hasPermi('mall:activityApplyInfo:list')")
    @PostMapping("/list")
    public ResponseEntity<Page<ActivityApplyInfo>> list(@RequestBody ActivityApplyInfoQuery query, Pageable page) {
        List<ActivityApplyInfo> list = service.selectList(query, page);
        return ResponseEntity.ok(new PageImpl<>(list, page, ((com.github.pagehelper.Page)list).getTotal()));
    }

    @ApiOperation("获取活动报名信息详细信息")
    @PreAuthorize("@ss.hasPermi('mall:activityApplyInfo:query')")
    @GetMapping(value = "/{id}")
    public ResponseEntity<ActivityApplyInfo> getInfo(@PathVariable("id") Long id) {
        return ResponseEntity.ok(service.selectById(id));
    }

    @ApiOperation("新增活动报名信息")
    @PreAuthorize("@ss.hasPermi('mall:activityApplyInfo:add')")
    @Log(title = "活动报名信息", businessType = BusinessType.INSERT)
    @PostMapping
    public ResponseEntity<Integer> add(@RequestBody ActivityApplyInfo activityApplyInfo) {
        return ResponseEntity.ok(service.insert(activityApplyInfo));
    }

    @ApiOperation("修改活动报名信息")
    @PreAuthorize("@ss.hasPermi('mall:activityApplyInfo:edit')")
    @Log(title = "活动报名信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public ResponseEntity<Integer> edit(@RequestBody ActivityApplyInfo activityApplyInfo) {
        return ResponseEntity.ok(service.update(activityApplyInfo));
    }

    @ApiOperation("删除活动报名信息")
    @PreAuthorize("@ss.hasPermi('mall:activityApplyInfo:remove')")
    @Log(title = "活动报名信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public ResponseEntity<Integer> remove(@PathVariable Long[] ids) {
        return ResponseEntity.ok(service.deleteByIds(ids));
    }
}
