package com.cyl.manager.oth.controller;
import java.util.List;

import com.cyl.manager.oth.domain.entity.AgreementInfo;
import com.cyl.manager.oth.domain.query.AgreementInfoQuery;
import com.cyl.manager.oth.domain.vo.AgreementInfoVO;
import com.cyl.manager.oth.service.AgreementInfoService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.Pageable;
import org.springframework.data.domain.Page;
import org.springframework.http.ResponseEntity;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
/**
 * 协议管理信息Controller
 *
 * @author zcc
 * @date 2024-08-01
 */
@Api(description ="协议管理信息接口列表")
@RestController
@RequestMapping("/oth/agreementInfo")
public class AgreementInfoController extends BaseController {
    @Autowired
    private AgreementInfoService service;



    @ApiOperation("查询协议管理信息列表")
    @PreAuthorize("@ss.hasPermi('oth:agreementInfo:list')")
    @PostMapping("/list")
    public ResponseEntity<Page<AgreementInfo>> list(@RequestBody AgreementInfoQuery query, Pageable page) {
        List<AgreementInfo> list = service.selectList(query, page);
        return ResponseEntity.ok(new PageImpl<>(list, page, ((com.github.pagehelper.Page)list).getTotal()));
    }

    @ApiOperation("获取协议管理信息详细信息")
    @PreAuthorize("@ss.hasPermi('oth:agreementInfo:query')")
    @GetMapping(value = "/{id}")
    public ResponseEntity<AgreementInfo> getInfo(@PathVariable("id") Long id) {
        return ResponseEntity.ok(service.selectById(id));
    }

    @ApiOperation("新增协议管理信息")
    @PreAuthorize("@ss.hasPermi('oth:agreementInfo:add')")
    @Log(title = "协议管理信息", businessType = BusinessType.INSERT)
    @PostMapping
    public ResponseEntity<Integer> add(@RequestBody AgreementInfo agreementInfo) {
        return ResponseEntity.ok(service.insert(agreementInfo));
    }

    @ApiOperation("修改协议管理信息")
    @PreAuthorize("@ss.hasPermi('oth:agreementInfo:edit')")
    @Log(title = "协议管理信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public ResponseEntity<Integer> edit(@RequestBody AgreementInfo agreementInfo) {
        return ResponseEntity.ok(service.update(agreementInfo));
    }

    @ApiOperation("删除协议管理信息")
    @PreAuthorize("@ss.hasPermi('oth:agreementInfo:remove')")
    @Log(title = "协议管理信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public ResponseEntity<Integer> remove(@PathVariable Long[] ids) {
        return ResponseEntity.ok(service.deleteByIds(ids));
    }
}
