package com.cyl.manager.oth.controller;
import java.util.List;

import com.cyl.manager.oth.domain.entity.BlackImgInfo;
import com.cyl.manager.oth.domain.query.BlackImgInfoQuery;
import com.cyl.manager.oth.service.BlackImgInfoService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.Pageable;
import org.springframework.data.domain.Page;
import org.springframework.http.ResponseEntity;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
/**
 * 背景图管理信息Controller
 *
 * @author zcc
 * @date 2024-08-01
 */
@Api(description ="背景图管理信息接口列表")
@RestController
@RequestMapping("/oth/blackImgInfo")
public class BlackImgInfoController extends BaseController {
    @Autowired
    private BlackImgInfoService service;


    @ApiOperation("查询背景图管理信息列表")
    @PreAuthorize("@ss.hasPermi('oth:blackImgInfo:list')")
    @PostMapping("/list")
    public ResponseEntity<Page<BlackImgInfo>> list(@RequestBody BlackImgInfoQuery query, Pageable page) {
        List<BlackImgInfo> list = service.selectList(query, page);
        return ResponseEntity.ok(new PageImpl<>(list, page, ((com.github.pagehelper.Page)list).getTotal()));
    }

    @ApiOperation("获取背景图管理信息详细信息")
    @PreAuthorize("@ss.hasPermi('oth:blackImgInfo:query')")
    @GetMapping(value = "/{id}")
    public ResponseEntity<BlackImgInfo> getInfo(@PathVariable("id") Long id) {
        return ResponseEntity.ok(service.selectById(id));
    }

    @ApiOperation("新增背景图管理信息")
    @PreAuthorize("@ss.hasPermi('oth:blackImgInfo:add')")
    @Log(title = "背景图管理信息", businessType = BusinessType.INSERT)
    @PostMapping
    public ResponseEntity<Integer> add(@RequestBody BlackImgInfo blackImgInfo) {
        return ResponseEntity.ok(service.insert(blackImgInfo));
    }

    @ApiOperation("修改背景图管理信息")
    @PreAuthorize("@ss.hasPermi('oth:blackImgInfo:edit')")
    @Log(title = "背景图管理信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public ResponseEntity<Integer> edit(@RequestBody BlackImgInfo blackImgInfo) {
        return ResponseEntity.ok(service.update(blackImgInfo));
    }

    @ApiOperation("删除背景图管理信息")
    @PreAuthorize("@ss.hasPermi('oth:blackImgInfo:remove')")
    @Log(title = "背景图管理信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public ResponseEntity<Integer> remove(@PathVariable Long[] ids) {
        return ResponseEntity.ok(service.deleteByIds(ids));
    }
}
