package com.cyl.manager.oth.controller;
import java.util.List;

import com.cyl.manager.oth.domain.entity.PosterInfo;
import com.cyl.manager.oth.domain.query.PosterInfoQuery;
import com.cyl.manager.oth.service.PosterInfoService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.Pageable;
import org.springframework.data.domain.Page;
import org.springframework.http.ResponseEntity;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
/**
 * 主引流海报信息Controller
 *
 * @author zcc
 * @date 2024-08-01
 */
@Api(description ="主引流海报信息接口列表")
@RestController
@RequestMapping("/oth/posterInfo")
public class PosterInfoController extends BaseController {
    @Autowired
    private PosterInfoService service;

    @ApiOperation("查询主引流海报信息列表")
    @PreAuthorize("@ss.hasPermi('oth:posterInfo:list')")
    @PostMapping("/list")
    public ResponseEntity<Page<PosterInfo>> list(@RequestBody PosterInfoQuery query, Pageable page) {
        List<PosterInfo> list = service.selectList(query, page);
        return ResponseEntity.ok(new PageImpl<>(list, page, ((com.github.pagehelper.Page)list).getTotal()));
    }


    @ApiOperation("获取主引流海报信息详细信息")
    @PreAuthorize("@ss.hasPermi('oth:posterInfo:query')")
    @GetMapping(value = "/{id}")
    public ResponseEntity<PosterInfo> getInfo(@PathVariable("id") Long id) {
        return ResponseEntity.ok(service.selectById(id));
    }

    @ApiOperation("新增主引流海报信息")
    @PreAuthorize("@ss.hasPermi('oth:posterInfo:add')")
    @Log(title = "主引流海报信息", businessType = BusinessType.INSERT)
    @PostMapping
    public ResponseEntity<Integer> add(@RequestBody PosterInfo posterInfo) {
        return ResponseEntity.ok(service.insert(posterInfo));
    }

    @ApiOperation("修改主引流海报信息")
    @PreAuthorize("@ss.hasPermi('oth:posterInfo:edit')")
    @Log(title = "主引流海报信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public ResponseEntity<Integer> edit(@RequestBody PosterInfo posterInfo) {
        return ResponseEntity.ok(service.update(posterInfo));
    }

    @ApiOperation("删除主引流海报信息")
    @PreAuthorize("@ss.hasPermi('oth:posterInfo:remove')")
    @Log(title = "主引流海报信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public ResponseEntity<Integer> remove(@PathVariable Long[] ids) {
        return ResponseEntity.ok(service.deleteByIds(ids));
    }
}
