package com.cyl.manager.oth.controller;
import java.util.List;

import com.cyl.manager.oth.domain.entity.SalesAddressInfo;
import com.cyl.manager.oth.domain.query.SalesAddressInfoQuery;
import com.cyl.manager.oth.service.SalesAddressInfoService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.Pageable;
import org.springframework.data.domain.Page;
import org.springframework.http.ResponseEntity;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
/**
 * 退货地址信息Controller
 *
 * @author zcc
 * @date 2024-08-01
 */
@Api(description ="退货地址信息接口列表")
@RestController
@RequestMapping("/oth/salesAddressInfo")
public class SalesAddressInfoController extends BaseController {
    @Autowired
    private SalesAddressInfoService service;

    @ApiOperation("查询退货地址信息列表")
    @PreAuthorize("@ss.hasPermi('oth:salesAddressInfo:list')")
    @PostMapping("/list")
    public ResponseEntity<Page<SalesAddressInfo>> list(@RequestBody SalesAddressInfoQuery query, Pageable page) {
        List<SalesAddressInfo> list = service.selectList(query, page);
        return ResponseEntity.ok(new PageImpl<>(list, page, ((com.github.pagehelper.Page)list).getTotal()));
    }


    @ApiOperation("获取退货地址信息详细信息")
    @PreAuthorize("@ss.hasPermi('oth:salesAddressInfo:query')")
    @GetMapping(value = "/{id}")
    public ResponseEntity<SalesAddressInfo> getInfo(@PathVariable("id") Long id) {
        return ResponseEntity.ok(service.selectById(id));
    }

    @ApiOperation("新增退货地址信息")
    @PreAuthorize("@ss.hasPermi('oth:salesAddressInfo:add')")
    @Log(title = "退货地址信息", businessType = BusinessType.INSERT)
    @PostMapping
    public ResponseEntity<Integer> add(@RequestBody SalesAddressInfo salesAddressInfo) {
        return ResponseEntity.ok(service.insert(salesAddressInfo));
    }

    @ApiOperation("修改退货地址信息")
    @PreAuthorize("@ss.hasPermi('oth:salesAddressInfo:edit')")
    @Log(title = "退货地址信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public ResponseEntity<Integer> edit(@RequestBody SalesAddressInfo salesAddressInfo) {
        return ResponseEntity.ok(service.update(salesAddressInfo));
    }

    @ApiOperation("删除退货地址信息")
    @PreAuthorize("@ss.hasPermi('oth:salesAddressInfo:remove')")
    @Log(title = "退货地址信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public ResponseEntity<Integer> remove(@PathVariable Long[] ids) {
        return ResponseEntity.ok(service.deleteByIds(ids));
    }
}
