package com.cyl.manager.oth.controller;
import java.util.List;

import com.cyl.manager.oth.domain.entity.SlideshowInfo;
import com.cyl.manager.oth.domain.query.SlideshowInfoQuery;
import com.cyl.manager.oth.service.SlideshowInfoService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.Pageable;
import org.springframework.data.domain.Page;
import org.springframework.http.ResponseEntity;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
/**
 * 轮播图信息Controller
 *
 * @author zcc
 * @date 2024-08-01
 */
@Api(description ="轮播图信息接口列表")
@RestController
@RequestMapping("/oth/slideshowInfo")
public class SlideshowInfoController extends BaseController {
    @Autowired
    private SlideshowInfoService service;


    @ApiOperation("查询轮播图信息列表")
    @PreAuthorize("@ss.hasPermi('oth:slideshowInfo:list')")
    @PostMapping("/list")
    public ResponseEntity<Page<SlideshowInfo>> list(@RequestBody SlideshowInfoQuery query, Pageable page) {
        List<SlideshowInfo> list = service.selectList(query, page);
        return ResponseEntity.ok(new PageImpl<>(list, page, ((com.github.pagehelper.Page)list).getTotal()));
    }



    @ApiOperation("获取轮播图信息详细信息")
    @PreAuthorize("@ss.hasPermi('oth:slideshowInfo:query')")
    @GetMapping(value = "/{id}")
    public ResponseEntity<SlideshowInfo> getInfo(@PathVariable("id") Long id) {
        return ResponseEntity.ok(service.selectById(id));
    }

    @ApiOperation("新增轮播图信息")
    @PreAuthorize("@ss.hasPermi('oth:slideshowInfo:add')")
    @Log(title = "轮播图信息", businessType = BusinessType.INSERT)
    @PostMapping
    public ResponseEntity<Integer> add(@RequestBody SlideshowInfo slideshowInfo) {
        return ResponseEntity.ok(service.insert(slideshowInfo));
    }

    @ApiOperation("修改轮播图信息")
    @PreAuthorize("@ss.hasPermi('oth:slideshowInfo:edit')")
    @Log(title = "轮播图信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public ResponseEntity<Integer> edit(@RequestBody SlideshowInfo slideshowInfo) {
        return ResponseEntity.ok(service.update(slideshowInfo));
    }

    @ApiOperation("删除轮播图信息")
    @PreAuthorize("@ss.hasPermi('oth:slideshowInfo:remove')")
    @Log(title = "轮播图信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{id}")
    public ResponseEntity<Integer> remove(@PathVariable Long id) {
        return ResponseEntity.ok(service.deleteByIds(id));
    }
}
