package com.cyl.manager.oth.service;

import java.util.Arrays;
import java.util.List;
import java.time.LocalDateTime;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.cyl.manager.oth.domain.entity.AgreementInfo;
import com.cyl.manager.oth.domain.query.AgreementInfoQuery;
import com.cyl.manager.oth.mapper.AgreementInfoMapper;
import com.github.pagehelper.PageHelper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Pageable;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;

/**
 * 协议管理信息Service业务层处理
 *
 * @author zcc
 */
@Service
public class AgreementInfoService {
    @Autowired
    private AgreementInfoMapper agreementInfoMapper;

    /**
     * 查询协议管理信息
     *
     * @param id 协议管理信息主键
     * @return 协议管理信息
     */
    public AgreementInfo selectById(Long id) {
        return agreementInfoMapper.selectById(id);
    }

    /**
     * 查询协议管理信息列表
     *
     * @param query 查询条件
     * @param page  分页条件
     * @return 协议管理信息
     */
    public List<AgreementInfo> selectList(AgreementInfoQuery query, Pageable page) {
        if (page != null) {
            PageHelper.startPage(page.getPageNumber() + 1, page.getPageSize());
        }
        LambdaQueryWrapper<AgreementInfo> qw = new LambdaQueryWrapper<>();
        return agreementInfoMapper.selectList(qw);
    }

    /**
     * 新增协议管理信息
     *
     * @param agreementInfo 协议管理信息
     * @return 结果
     */
    public int insert(AgreementInfo agreementInfo) {
        agreementInfo.setCreateTime(LocalDateTime.now());
        return agreementInfoMapper.insert(agreementInfo);
    }

    /**
     * 修改协议管理信息
     *
     * @param agreementInfo 协议管理信息
     * @return 结果
     */
    public int update(AgreementInfo agreementInfo) {
        return agreementInfoMapper.updateById(agreementInfo);
    }

    /**
     * 批量删除协议管理信息
     *
     * @param ids 需要删除的协议管理信息主键
     * @return 结果
     */
    public int deleteByIds(Long[] ids) {
        return agreementInfoMapper.updateDelFlagByIds(ids);
    }

    /**
     * 删除协议管理信息信息
     *
     * @param id 协议管理信息主键
     * @return 结果
     */
    public int deleteById(Long id) {
        Long[] ids = {id};
        return agreementInfoMapper.updateDelFlagByIds(ids);
    }
}
