package com.cyl.manager.oth.service;
import java.util.Arrays;
import java.util.List;
import java.time.LocalDateTime;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.cyl.manager.oth.domain.entity.BlackImgInfo;
import com.cyl.manager.oth.domain.query.BlackImgInfoQuery;
import com.cyl.manager.oth.mapper.BlackImgInfoMapper;
import com.github.pagehelper.PageHelper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Pageable;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;


/**
 * 背景图管理信息Service业务层处理
 *
 *
 * @author zcc
 */
@Service
public class BlackImgInfoService {
    @Autowired
    private BlackImgInfoMapper blackImgInfoMapper;

    /**
     * 查询背景图管理信息
     *
     * @param id 背景图管理信息主键
     * @return 背景图管理信息
     */
    public BlackImgInfo selectById(Long id) {
        return blackImgInfoMapper.selectById(id);
    }

    /**
     * 查询背景图管理信息列表
     *
     * @param query 查询条件
     * @param page 分页条件
     * @return 背景图管理信息
     */
    public List<BlackImgInfo> selectList(BlackImgInfoQuery query, Pageable page) {
        if (page != null) {
            PageHelper.startPage(page.getPageNumber() + 1, page.getPageSize());
        }
        QueryWrapper<BlackImgInfo> qw = new QueryWrapper<>();
        return blackImgInfoMapper.selectList(qw);
    }

    /**
     * 新增背景图管理信息
     *
     * @param blackImgInfo 背景图管理信息
     * @return 结果
     */
    public int insert(BlackImgInfo blackImgInfo) {
        blackImgInfo.setCreateTime(LocalDateTime.now());
        return blackImgInfoMapper.insert(blackImgInfo);
    }

    /**
     * 修改背景图管理信息
     *
     * @param blackImgInfo 背景图管理信息
     * @return 结果
     */
    public int update(BlackImgInfo blackImgInfo) {
        return blackImgInfoMapper.updateById(blackImgInfo);
    }

    /**
     * 批量删除背景图管理信息
     *
     * @param ids 需要删除的背景图管理信息主键
     * @return 结果
     */
    public int deleteByIds(Long[] ids) {
        return blackImgInfoMapper.updateDelFlagByIds(ids);
    }

    /**
     * 删除背景图管理信息信息
     *
     * @param id 背景图管理信息主键
     * @return 结果
     */
    public int deleteById(Long id) {
        Long[] ids = {id};
        return blackImgInfoMapper.updateDelFlagByIds(ids);
    }
}
