package com.cyl.manager.oth.service;

import java.util.Arrays;
import java.util.List;
import java.time.LocalDateTime;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.cyl.manager.oth.domain.entity.PosterInfo;
import com.cyl.manager.oth.domain.query.PosterInfoQuery;
import com.cyl.manager.oth.mapper.PosterInfoMapper;
import com.github.pagehelper.PageHelper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Pageable;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;

/**
 * 主引流海报信息Service业务层处理
 *
 *
 * @author zcc
 */
@Service
public class PosterInfoService {
    @Autowired
    private PosterInfoMapper posterInfoMapper;

    /**
     * 查询主引流海报信息
     *
     * @param id 主引流海报信息主键
     * @return 主引流海报信息
     */
    public PosterInfo selectById(Long id) {
        return posterInfoMapper.selectById(id);
    }

    /**
     * 查询主引流海报信息列表
     *
     * @param query 查询条件
     * @param page 分页条件
     * @return 主引流海报信息
     */
    public List<PosterInfo> selectList(PosterInfoQuery query, Pageable page) {
        if (page != null) {
            PageHelper.startPage(page.getPageNumber() + 1, page.getPageSize());
        }
        QueryWrapper<PosterInfo> qw = new QueryWrapper<>();

        String posterUrl = query.getPosterUrl();
        if (!StringUtils.isEmpty(posterUrl)) {
            qw.eq("poster_url", posterUrl);
        }
        String skipLink = query.getSkipLink();
        if (!StringUtils.isEmpty(skipLink)) {
            qw.eq("skip_link", skipLink);
        }
        return posterInfoMapper.selectList(qw);
    }

    /**
     * 新增主引流海报信息
     *
     * @param posterInfo 主引流海报信息
     * @return 结果
     */
    public int insert(PosterInfo posterInfo) {
        posterInfo.setCreateTime(LocalDateTime.now());
        return posterInfoMapper.insert(posterInfo);
    }

    /**
     * 修改主引流海报信息
     *
     * @param posterInfo 主引流海报信息
     * @return 结果
     */
    public int update(PosterInfo posterInfo) {
        return posterInfoMapper.updateById(posterInfo);
    }

    /**
     * 批量删除主引流海报信息
     *
     * @param ids 需要删除的主引流海报信息主键
     * @return 结果
     */
    public int deleteByIds(Long[] ids) {
        return posterInfoMapper.updateDelFlagByIds(ids);
    }

    /**
     * 删除主引流海报信息信息
     *
     * @param id 主引流海报信息主键
     * @return 结果
     */
    public int deleteById(Long id) {
        Long[] ids = {id};
        return posterInfoMapper.updateDelFlagByIds(ids);
    }
}
